@@ -4,12 +4,12 @@ import { AppEvents, isTruthy, locationUtil } from '@grafana/data';
 import { t } from '@grafana/i18n';
 import { config, getBackendSrv, isFetchError, locationService } from '@grafana/runtime';
 import { Dashboard } from '@grafana/schema';
-import { Spec as DashboardV2Spec } from '@grafana/schema/dist/esm/schema/dashboard/v2alpha1/types.spec.gen';
-import { folderAPIv1beta1 as folderAPI } from 'app/api/clients/folder/v1beta1';
+import { Spec as DashboardV2Spec } from '@grafana/schema/dist/esm/schema/dashboard/v2';
+import { isProvisionedFolderCheck } from 'app/api/clients/folder/v1beta1/utils';
 import { createBaseQuery, handleRequestError } from 'app/api/createBaseQuery';
 import appEvents from 'app/core/app_events';
 import { contextSrv } from 'app/core/core';
-import { Resource, ResourceList } from 'app/features/apiserver/types';
+import { AnnoKeyFolder, Resource, ResourceList } from 'app/features/apiserver/types';
 import { getDashboardAPI } from 'app/features/dashboard/api/dashboard_api';
 import { isDashboardV2Resource, isV1DashboardCommand, isV2DashboardCommand } from 'app/features/dashboard/api/utils';
 import { SaveDashboardCommand } from 'app/features/dashboard/components/SaveDashboard/types';
@@ -19,17 +19,34 @@ import { PermissionLevelString } from 'app/types/acl';
 import { SaveDashboardResponseDTO, ImportDashboardResponseDTO } from 'app/types/dashboard';
 import { FolderListItemDTO, FolderDTO, DescendantCount, DescendantCountDTO } from 'app/types/folders';
 
+import { getDashboardScenePageStateManager } from '../../dashboard-scene/pages/DashboardScenePageStateManager';
+import { deletedDashboardsCache } from '../../search/service/deletedDashboardsCache';
 import { refetchChildren, refreshParents } from '../state/actions';
 import { DashboardTreeSelection } from '../types';
 
-import { isProvisionedDashboard, isProvisionedFolder } from './isProvisioned';
+import { isProvisionedDashboard } from './isProvisioned';
 import { PAGE_SIZE } from './services';
 
-interface DeleteItemsArgs {
-  selectedItems: Omit<DashboardTreeSelection, 'panel' | '$all'>;
+export interface DeleteFoldersArgs {
+  folderUIDs: string[];
 }
 
-interface MoveItemsArgs extends DeleteItemsArgs {
+interface DeleteDashboardsArgs {
+  dashboardUIDs: string[];
+}
+
+interface MoveDashboardsArgs {
+  destinationUID: string;
+  dashboardUIDs: string[];
+}
+
+export interface MoveFoldersArgs {
+  destinationUID: string;
+  folderUIDs: string[];
+}
+
+export interface MoveFolderArgs {
+  folderUID: string;
   destinationUID: string;
 }
 
@@ -93,7 +110,6 @@ export const browseDashboardsAPI = createApi({
       }),
       onQueryStarted: ({ parentUid }, { queryFulfilled, dispatch }) => {
         queryFulfilled.then(async ({ data: folder }) => {
-          await contextSrv.fetchUserPermissions();
           dispatch(
             refetchChildren({
               parentUID: parentUid,
@@ -105,7 +121,7 @@ export const browseDashboardsAPI = createApi({
     }),
 
     // save an existing folder (e.g. rename)
-    saveFolder: builder.mutation<FolderDTO, FolderDTO>({
+    saveFolder: builder.mutation<FolderDTO, Pick<FolderDTO, 'uid' | 'title' | 'version' | 'parentUid'>>({
       // because the getFolder calls contain the parents, renaming a parent/grandparent/etc needs to invalidate all child folders
       // we could do something smart and recursively invalidate these child folders but it doesn't seem worth it
       // instead let's just invalidate all the getFolder calls
@@ -131,22 +147,16 @@ export const browseDashboardsAPI = createApi({
     }),
 
     // move an *individual* folder. used in the folder actions menu.
-    moveFolder: builder.mutation<void, { folder: FolderDTO; destinationUID: string }>({
+    moveFolder: builder.mutation<void, MoveFolderArgs>({
       invalidatesTags: ['getFolder'],
-      query: ({ folder, destinationUID }) => ({
-        url: `/folders/${folder.uid}/move`,
+      query: ({ folderUID, destinationUID }) => ({
+        url: `/folders/${folderUID}/move`,
         method: 'POST',
         body: { parentUID: destinationUID },
       }),
-      onQueryStarted: ({ folder, destinationUID }, { queryFulfilled, dispatch }) => {
-        const { parentUid } = folder;
+      onQueryStarted: ({ folderUID, destinationUID }, { queryFulfilled, dispatch }) => {
         queryFulfilled.then(() => {
-          dispatch(
-            refetchChildren({
-              parentUID: parentUid,
-              pageSize: PAGE_SIZE,
-            })
-          );
+          dispatch(refreshParents([folderUID]));
           dispatch(
             refetchChildren({
               parentUID: destinationUID,
@@ -201,8 +211,7 @@ export const browseDashboardsAPI = createApi({
         };
 
         for (const folderCounts of results) {
-          // TODO remove nullish coalescing once nestedFolders is toggled on
-          totalCounts.folder += folderCounts.folder ?? 0;
+          totalCounts.folder += folderCounts.folder;
           totalCounts.dashboard += folderCounts.dashboard;
           totalCounts.alertRule += folderCounts.alertrule;
           totalCounts.libraryPanel += folderCounts.librarypanel;
@@ -212,37 +221,13 @@ export const browseDashboardsAPI = createApi({
       },
     }),
 
-    // move *multiple* items (folders and dashboards). used in the move modal.
-    moveItems: builder.mutation<void, MoveItemsArgs>({
+    // move *multiple* dashboards. used in the move modal.
+    moveDashboards: builder.mutation<void, MoveDashboardsArgs>({
       invalidatesTags: ['getFolder'],
-      queryFn: async ({ selectedItems, destinationUID }, _api, _extraOptions, baseQuery) => {
-        const selectedDashboards = Object.keys(selectedItems.dashboard).filter((uid) => selectedItems.dashboard[uid]);
-        const selectedFolders = Object.keys(selectedItems.folder).filter((uid) => selectedItems.folder[uid]);
-
-        // Move all the folders sequentially
-        // TODO error handling here
-        for (const folderUID of selectedFolders) {
-          if (config.featureToggles.provisioning) {
-            const folder = await dispatch(folderAPI.endpoints.getFolder.initiate({ name: folderUID }));
-            if (isProvisionedFolder(folder.data)) {
-              appEvents.publish({
-                type: AppEvents.alertWarning.name,
-                payload: ['Cannot move provisioned folder'],
-              });
-              continue;
-            }
-          }
-
-          await baseQuery({
-            url: `/folders/${folderUID}/move`,
-            method: 'POST',
-            body: { parentUID: destinationUID },
-          });
-        }
-
+      queryFn: async ({ dashboardUIDs, destinationUID }, _api, _extraOptions, baseQuery) => {
         // Move all the dashboards sequentially
         // TODO error handling here
-        for (const dashboardUID of selectedDashboards) {
+        for (const dashboardUID of dashboardUIDs) {
           const fullDash = await getDashboardAPI().getDashboardDTO(dashboardUID);
           const dashboard = isDashboardV2Resource(fullDash) ? fullDash.spec : fullDash.dashboard;
           const k8s = isDashboardV2Resource(fullDash) ? fullDash.metadata : undefined;
@@ -266,9 +251,7 @@ export const browseDashboardsAPI = createApi({
         }
         return { data: undefined };
       },
-      onQueryStarted: ({ destinationUID, selectedItems }, { queryFulfilled, dispatch }) => {
-        const selectedDashboards = Object.keys(selectedItems.dashboard).filter((uid) => selectedItems.dashboard[uid]);
-        const selectedFolders = Object.keys(selectedItems.folder).filter((uid) => selectedItems.folder[uid]);
+      onQueryStarted: ({ destinationUID, dashboardUIDs }, { queryFulfilled, dispatch }) => {
         queryFulfilled.then(() => {
           dispatch(
             refetchChildren({
@@ -276,31 +259,61 @@ export const browseDashboardsAPI = createApi({
               pageSize: PAGE_SIZE,
             })
           );
-          dispatch(refreshParents([...selectedFolders, ...selectedDashboards]));
+          dispatch(refreshParents(dashboardUIDs));
         });
       },
     }),
 
-    // delete *multiple* items (folders and dashboards). used in the delete modal.
-    deleteItems: builder.mutation<void, DeleteItemsArgs>({
+    // move *multiple* folders. used in the move modal.
+    moveFolders: builder.mutation<void, MoveFoldersArgs>({
       invalidatesTags: ['getFolder'],
-      queryFn: async ({ selectedItems }, _api, _extraOptions, baseQuery) => {
-        const selectedDashboards = Object.keys(selectedItems.dashboard).filter((uid) => selectedItems.dashboard[uid]);
-        const selectedFolders = Object.keys(selectedItems.folder).filter((uid) => selectedItems.folder[uid]);
+      queryFn: async ({ folderUIDs, destinationUID }, _api, _extraOptions, baseQuery) => {
+        // Move all the folders sequentially
+        // TODO error handling here
+        for (const folderUID of folderUIDs) {
+          if (
+            await isProvisionedFolderCheck(dispatch, folderUID, {
+              warning: t(
+                'folders.api.folder-move-error-provisioned',
+                'Cannot move provisioned folder. To move it, move it in the repository and synchronise to apply the changes.'
+              ),
+            })
+          ) {
+            continue;
+          }
+
+          await baseQuery({
+            url: `/folders/${folderUID}/move`,
+            method: 'POST',
+            body: { parentUID: destinationUID },
+          });
+        }
+
+        return { data: undefined };
+      },
+      onQueryStarted: ({ destinationUID, folderUIDs }, { queryFulfilled, dispatch }) => {
+        queryFulfilled.then(() => {
+          dispatch(
+            refetchChildren({
+              parentUID: destinationUID,
+              pageSize: PAGE_SIZE,
+            })
+          );
+          dispatch(refreshParents(folderUIDs));
+        });
+      },
+    }),
+
+    // delete *multiple* folders. used in the delete modal.
+    deleteFolders: builder.mutation<void, DeleteFoldersArgs>({
+      invalidatesTags: ['getFolder'],
+      queryFn: async ({ folderUIDs }, _api, _extraOptions, baseQuery) => {
         // Delete all the folders sequentially
         // TODO error handling here
-        for (const folderUID of selectedFolders) {
-          if (config.featureToggles.provisioning) {
-            const folder = await dispatch(folderAPI.endpoints.getFolder.initiate({ name: folderUID }));
-            if (isProvisionedFolder(folder.data)) {
-              appEvents.publish({
-                type: AppEvents.alertWarning.name,
-                payload: [
-                  'Cannot delete provisioned folder. To remove it, delete it from the repository and synchronise to apply the changes.',
-                ],
-              });
-              continue;
-            }
+        for (const folderUID of folderUIDs) {
+          // This also shows warning alert
+          if (await isProvisionedFolderCheck(dispatch, folderUID)) {
+            continue;
           }
           await baseQuery({
             url: `/folders/${folderUID}`,
@@ -312,9 +325,25 @@ export const browseDashboardsAPI = createApi({
             },
           });
         }
+        return { data: undefined };
+      },
+      onQueryStarted: ({ folderUIDs }, { queryFulfilled, dispatch }) => {
+        queryFulfilled.then(() => {
+          dispatch(refreshParents(folderUIDs));
+          // Clear the deleted dashboards cache since deleting a folder also deletes its dashboards
+          deletedDashboardsCache.clear();
+        });
+      },
+    }),
+
+    // delete *multiple* dashboards. used in the delete modal.
+    deleteDashboards: builder.mutation<void, DeleteDashboardsArgs>({
+      invalidatesTags: ['getFolder'],
+      queryFn: async ({ dashboardUIDs }, _api, _extraOptions, baseQuery) => {
+        const pageStateManager = getDashboardScenePageStateManager();
         // Delete all the dashboards sequentially
         // TODO error handling here
-        for (const dashboardUID of selectedDashboards) {
+        for (const dashboardUID of dashboardUIDs) {
           if (config.featureToggles.provisioning) {
             const dto = await getDashboardAPI().getDashboardDTO(dashboardUID);
             if (isProvisionedDashboard(dto)) {
@@ -331,6 +360,10 @@ export const browseDashboardsAPI = createApi({
 
           await getDashboardAPI().deleteDashboard(dashboardUID, true);
 
+          pageStateManager.clearDashboardCache();
+          pageStateManager.removeSceneCache(dashboardUID);
+          deletedDashboardsCache.clear();
+
           // handling success alerts for these feature toggles
           // for legacy response, the success alert will be triggered by showSuccessAlert function in public/app/core/services/backend_srv.ts
           if (config.featureToggles.kubernetesDashboards) {
@@ -342,11 +375,9 @@ export const browseDashboardsAPI = createApi({
         }
         return { data: undefined };
       },
-      onQueryStarted: ({ selectedItems }, { queryFulfilled, dispatch }) => {
-        const selectedDashboards = Object.keys(selectedItems.dashboard).filter((uid) => selectedItems.dashboard[uid]);
-        const selectedFolders = Object.keys(selectedItems.folder).filter((uid) => selectedItems.folder[uid]);
+      onQueryStarted: ({ dashboardUIDs }, { queryFulfilled, dispatch }) => {
         queryFulfilled.then(() => {
-          dispatch(refreshParents([...selectedFolders, ...selectedDashboards]));
+          dispatch(refreshParents(dashboardUIDs));
         });
       },
     }),
@@ -444,6 +475,7 @@ export const browseDashboardsAPI = createApi({
 
     // RTK wrapper for the dashboard API
     listDeletedDashboards: builder.query<ResourceList<Dashboard | DashboardV2Spec>, void>({
+      providesTags: ['getFolder'],
       queryFn: async () => {
         try {
           const api = getDashboardAPI();
@@ -458,17 +490,27 @@ export const browseDashboardsAPI = createApi({
 
     // restore a dashboard that got deleted
     restoreDashboard: builder.mutation<void, RestoreDashboardArgs>({
+      invalidatesTags: ['getFolder'],
       queryFn: async ({ dashboard }) => {
         try {
           const api = getDashboardAPI();
           const response = await api.restoreDashboard(dashboard);
           const name = response.spec.title;
+          const parentFolder = response.metadata?.annotations?.[AnnoKeyFolder];
 
           if (name) {
             appEvents.publish({
               type: AppEvents.alertSuccess.name,
               payload: [t('browse-dashboards.restore.success', 'Dashboard {{name}} restored', { name })],
             });
+
+            // Refresh the contents of the folder a dashboard was restored to
+            dispatch(
+              refetchChildren({
+                parentUID: parentFolder,
+                pageSize: PAGE_SIZE,
+              })
+            );
           }
 
           return { data: undefined };
@@ -483,12 +525,14 @@ export const browseDashboardsAPI = createApi({
 export const {
   endpoints,
   useDeleteFolderMutation,
-  useDeleteItemsMutation,
+  useDeleteFoldersMutation,
+  useDeleteDashboardsMutation,
   useGetAffectedItemsQuery,
   useGetFolderQuery,
   useLazyGetFolderQuery,
   useMoveFolderMutation,
-  useMoveItemsMutation,
+  useMoveDashboardsMutation,
+  useMoveFoldersMutation,
   useNewFolderMutation,
   useSaveDashboardMutation,
   useSaveFolderMutation,
