@@ -1,4 +1,4 @@
-import { ExploreQueryParams } from 'app/types';
+import { ExploreQueryParams } from 'app/types/explore';
 
 import { v0Migrator } from './migrators/v0';
 import { ExploreURLV1, v1Migrator } from './migrators/v1';
