@@ -1,8 +1,9 @@
-import React from 'react';
 import { css } from '@emotion/css';
-import { GrafanaTheme2, PluginSignatureStatus } from '@grafana/data';
+import * as React from 'react';
+
+import { GrafanaTheme2 } from '@grafana/data';
 import { PluginSignatureBadge, useStyles2 } from '@grafana/ui';
-import { PluginSignatureDetailsBadge } from './PluginSignatureDetailsBadge';
+
 import { CatalogPlugin } from '../types';
 
 type Props = {
@@ -12,7 +13,6 @@ type Props = {
 // Designed to show plugin signature information in the header on the plugin's details page
 export function PluginDetailsHeaderSignature({ plugin }: Props): React.ReactElement {
   const styles = useStyles2(getStyles);
-  const isSignatureValid = plugin.signature === PluginSignatureStatus.valid;
 
   return (
     <div className={styles.container}>
@@ -22,24 +22,26 @@ export function PluginDetailsHeaderSignature({ plugin }: Props): React.ReactElem
         rel="noreferrer"
         className={styles.link}
       >
-        <PluginSignatureBadge status={plugin.signature} />
+        <PluginSignatureBadge
+          status={plugin.signature}
+          signatureType={plugin.signatureType}
+          signatureOrg={plugin.signatureOrg}
+        />
       </a>
-
-      {isSignatureValid && (
-        <PluginSignatureDetailsBadge signatureType={plugin.signatureType} signatureOrg={plugin.signatureOrg} />
-      )}
     </div>
   );
 }
 
 export const getStyles = (theme: GrafanaTheme2) => {
   return {
-    container: css`
-      display: flex;
-    `,
-    link: css`
-      display: inline-flex;
-      align-items: center;
-    `,
+    container: css({
+      display: 'flex',
+      flexWrap: 'wrap',
+      gap: theme.spacing(0.5),
+    }),
+    link: css({
+      display: 'inline-flex',
+      alignItems: 'center',
+    }),
   };
 };
