@@ -12,11 +12,11 @@ import {
   TimeRange,
   toUtc,
 } from '@grafana/data';
-import { FetchResponse, reportInteraction, getBackendSrv, setBackendSrv, BackendSrv } from '@grafana/runtime';
+import { FetchResponse, reportInteraction, getBackendSrv, setBackendSrv, BackendSrv, config } from '@grafana/runtime';
 
+import { ElasticsearchDataQuery, Filters } from './dataquery.gen';
 import { ElasticDatasource } from './datasource';
 import { createElasticDatasource, createElasticQuery, mockResponseFrames } from './mocks';
-import { Filters, ElasticsearchQuery } from './types';
 
 const originalConsoleError = console.error;
 jest.mock('@grafana/runtime', () => ({
@@ -121,6 +121,48 @@ describe('ElasticDatasource', () => {
       expect(gte).toBe('1663740610000'); // 2022-09-21T06:10:10Z
       expect(lte).toBe('1663999821000'); // 2022-09-24T06:10:21Z
     });
+
+    it('should return fields properly', async () => {
+      const ds = createElasticDatasource({ jsonData: { timeField: '@timestamp' } });
+      const getTagValuesData = {
+        responses: [
+          {
+            aggregations: {
+              '1': {
+                buckets: [
+                  {
+                    doc_count: 10,
+                    key: 'foo',
+                  },
+                  {
+                    doc_count: 20,
+                    key: 6,
+                    key_as_string: 'six',
+                  },
+                  {
+                    doc_count: 30,
+                    key: 7,
+                  },
+                ],
+              },
+            },
+          },
+        ],
+      };
+      const postResource = jest.spyOn(ds, 'postResourceRequest').mockResolvedValue(getTagValuesData);
+      const values = await ds.getTagValues({ key: 'test', timeRange: timeRangeMock, filters: [] });
+      expect(postResource).toHaveBeenCalledTimes(1);
+
+      expect(values.length).toBe(3);
+      expect(values[0].text).toBe('foo');
+      expect(values[0].value).toBe('foo');
+
+      expect(values[1].text).toBe('six');
+      expect(values[1].value).toBe('6');
+
+      expect(values[2].text).toBe('7');
+      expect(values[2].value).toBe('7');
+    });
   });
 
   describe('query', () => {
@@ -228,7 +270,7 @@ describe('ElasticDatasource', () => {
               refId: 'A',
               metrics: [{ type: 'logs', id: '1' }],
               query: 'foo="bar"',
-            } as ElasticsearchQuery,
+            } as ElasticsearchDataQuery,
           ],
           app: CoreApp.Explore,
         };
@@ -257,7 +299,7 @@ describe('ElasticDatasource', () => {
               refId: 'A',
               metrics: [{ type: 'raw_data', id: '1' }],
               query: 'foo="bar"',
-            } as ElasticsearchQuery,
+            } as ElasticsearchDataQuery,
           ],
           app: CoreApp.Explore,
         };
@@ -286,7 +328,7 @@ describe('ElasticDatasource', () => {
               refId: 'A',
               metrics: [{ type: 'raw_data', id: '1' }],
               query: 'foo="bar"',
-            } as ElasticsearchQuery,
+            } as ElasticsearchDataQuery,
           ],
           app: CoreApp.Dashboard,
         };
@@ -300,7 +342,7 @@ describe('ElasticDatasource', () => {
 
   describe('interpolateVariablesInQueries', () => {
     it('should correctly interpolate variables in query', () => {
-      const query: ElasticsearchQuery = {
+      const query: ElasticsearchDataQuery = {
         refId: 'A',
         bucketAggs: [{ type: 'filters', settings: { filters: [{ query: '$var', label: '' }] }, id: '1' }],
         metrics: [{ type: 'count', id: '1' }],
@@ -314,7 +356,7 @@ describe('ElasticDatasource', () => {
 
     it('should correctly add ad hoc filters when interpolating variables in query', () => {
       const adHocFilters = [{ key: 'bar', operator: '=', value: 'test' }];
-      const query: ElasticsearchQuery = {
+      const query: ElasticsearchDataQuery = {
         refId: 'A',
         bucketAggs: [{ type: 'filters', settings: { filters: [{ query: '$var', label: '' }] }, id: '1' }],
         metrics: [{ type: 'count', id: '1' }],
@@ -326,7 +368,7 @@ describe('ElasticDatasource', () => {
     });
 
     it('should correctly handle empty query strings in filters bucket aggregation', () => {
-      const query: ElasticsearchQuery = {
+      const query: ElasticsearchDataQuery = {
         refId: 'A',
         bucketAggs: [{ type: 'filters', settings: { filters: [{ query: '', label: '' }] }, id: '1' }],
         metrics: [{ type: 'count', id: '1' }],
@@ -353,6 +395,20 @@ describe('ElasticDatasource', () => {
       ).toEqual(undefined);
     });
 
+    it('does not return logs volume query for hidden query', () => {
+      expect(
+        ds.getSupplementaryQuery(
+          { type: SupplementaryQueryType.LogsVolume },
+          {
+            refId: 'A',
+            metrics: [{ type: 'logs', id: '1' }],
+            query: 'foo="bar"',
+            hide: true,
+          }
+        )
+      ).toEqual(undefined);
+    });
+
     it('returns logs volume query for log query', () => {
       expect(
         ds.getSupplementaryQuery(
@@ -417,11 +473,25 @@ describe('ElasticDatasource', () => {
         metrics: [{ type: 'logs', id: '1', settings: { limit: '100' } }],
       });
     });
+
+    it('does not return logs samples for hidden time series queries', () => {
+      expect(
+        ds.getSupplementaryQuery(
+          { type: SupplementaryQueryType.LogsSample, limit: 100 },
+          {
+            refId: 'A',
+            query: '',
+            bucketAggs: [{ type: 'date_histogram', id: '1' }],
+            hide: true,
+          }
+        )
+      ).toEqual(undefined);
+    });
   });
 
   describe('getDataProvider', () => {
     it('does not create a logs sample provider for non time series query', () => {
-      const options: DataQueryRequest<ElasticsearchQuery> = {
+      const options: DataQueryRequest<ElasticsearchDataQuery> = {
         ...dataQueryDefaults,
         targets: [
           {
@@ -434,8 +504,23 @@ describe('ElasticDatasource', () => {
       expect(ds.getSupplementaryRequest(SupplementaryQueryType.LogsSample, options)).not.toBeDefined();
     });
 
+    it('does not create a logs volume provider for hidden queries', () => {
+      const options: DataQueryRequest<ElasticsearchDataQuery> = {
+        ...dataQueryDefaults,
+        targets: [
+          {
+            refId: 'A',
+            metrics: [{ type: 'logs', id: '1', settings: { limit: '100' } }],
+            hide: true,
+          },
+        ],
+      };
+
+      expect(ds.getSupplementaryRequest(SupplementaryQueryType.LogsVolume, options)).not.toBeDefined();
+    });
+
     it('does create a logs sample provider for time series query', () => {
-      const options: DataQueryRequest<ElasticsearchQuery> = {
+      const options: DataQueryRequest<ElasticsearchDataQuery> = {
         ...dataQueryDefaults,
         targets: [
           {
@@ -451,7 +536,7 @@ describe('ElasticDatasource', () => {
 
   describe('getLogsSampleDataProvider', () => {
     it("doesn't return a logs sample provider given a non time series query", () => {
-      const request: DataQueryRequest<ElasticsearchQuery> = {
+      const request: DataQueryRequest<ElasticsearchDataQuery> = {
         ...dataQueryDefaults,
         targets: [
           {
@@ -465,7 +550,7 @@ describe('ElasticDatasource', () => {
     });
 
     it('returns a logs sample provider given a time series query', () => {
-      const request: DataQueryRequest<ElasticsearchQuery> = {
+      const request: DataQueryRequest<ElasticsearchDataQuery> = {
         ...dataQueryDefaults,
         targets: [
           {
@@ -492,7 +577,7 @@ describe('ElasticDatasource', () => {
   });
 
   describe('modifyQuery', () => {
-    let query: ElasticsearchQuery;
+    let query: ElasticsearchDataQuery;
     beforeEach(() => {
       query = { query: '', refId: 'A' };
     });
@@ -518,7 +603,7 @@ describe('ElasticDatasource', () => {
       });
 
       describe('with non-empty query', () => {
-        let query: ElasticsearchQuery;
+        let query: ElasticsearchDataQuery;
         beforeEach(() => {
           query = { query: 'test:"value"', refId: 'A' };
         });
@@ -560,7 +645,7 @@ describe('ElasticDatasource', () => {
     });
 
     describe('with non-empty query', () => {
-      let query: ElasticsearchQuery;
+      let query: ElasticsearchDataQuery;
       beforeEach(() => {
         query = { query: 'test:"value"', refId: 'A' };
       });
@@ -580,7 +665,7 @@ describe('ElasticDatasource', () => {
 
     describe('toggleQueryFilter', () => {
       describe('with empty query', () => {
-        let query: ElasticsearchQuery;
+        let query: ElasticsearchDataQuery;
         beforeEach(() => {
           query = { query: '', refId: 'A' };
         });
@@ -613,7 +698,7 @@ describe('ElasticDatasource', () => {
       });
 
       describe('with non-empty query', () => {
-        let query: ElasticsearchQuery;
+        let query: ElasticsearchDataQuery;
         beforeEach(() => {
           query = { query: 'test:"value"', refId: 'A' };
         });
@@ -721,6 +806,19 @@ describe('ElasticDatasource', () => {
           const query = ds.addAdHocFilters('', filters);
           expect(query).toBe('field\\:name:"field \\"value\\""');
         });
+
+        it('should not escape backslash in regex', () => {
+          const filters = [{ key: 'field:name', operator: '=~', value: 'field value\\/', condition: '' }];
+          const query = ds.addAdHocFilters('', filters);
+          expect(query).toBe('field\\:name:/field value\\//');
+        });
+
+        it('should replace level with the log level field', () => {
+          const ds = createElasticDatasource({ jsonData: { logLevelField: 'level_field' } });
+          const filters = [{ key: 'level', operator: '=', value: 'foo', condition: '' }];
+          const query = ds.addAdHocFilters('', filters);
+          expect(query).toBe('level_field:"foo"');
+        });
       });
     });
 
@@ -746,7 +844,7 @@ describe('ElasticDatasource', () => {
   });
 
   describe('targetContainsTemplate', () => {
-    let target: ElasticsearchQuery;
+    let target: ElasticsearchDataQuery;
     beforeEach(() => {
       target = {
         refId: 'test',
@@ -1029,6 +1127,10 @@ describe('ElasticDatasource', () => {
                     key: 'test2',
                     key_as_string: 'test2_as_string',
                   },
+                  {
+                    doc_count: 2,
+                    key: 5,
+                  },
                 ],
               },
             },
@@ -1053,13 +1155,14 @@ describe('ElasticDatasource', () => {
 
     it('should get results', async () => {
       const { results } = await runScenario();
-      expect(results.length).toEqual(2);
+      expect(results.length).toEqual(3);
     });
 
-    it('should use key or key_as_string', async () => {
+    it('should use key, key_as_string, or cast key to string', async () => {
       const { results } = await runScenario();
       expect(results[0].text).toEqual('test');
       expect(results[1].text).toEqual('test2_as_string');
+      expect(results[2].text).toEqual('5');
     });
 
     it('should not set search type to count', async () => {
@@ -1247,4 +1350,191 @@ describe('ElasticDatasource', () => {
       });
     });
   });
+
+  describe('getFieldsFieldCap', () => {
+    const originalFeatureToggleValue = config.featureToggles.elasticsearchCrossClusterSearch;
+
+    afterEach(() => {
+      config.featureToggles.elasticsearchCrossClusterSearch = originalFeatureToggleValue;
+    });
+    const getFieldsMockData = {
+      fields: {
+        '@timestamp_millis': {
+          date: {
+            type: 'date',
+            metadata_field: false,
+          },
+        },
+        classification_terms: {
+          keyword: {
+            type: 'keyword',
+            metadata_field: false,
+          },
+        },
+        ip_address: {
+          ip: {
+            type: 'ip',
+            metadata_field: false,
+          },
+        },
+        'justification_blob.criterion.keyword': {
+          keyword: {
+            type: 'keyword',
+            metadata_field: false,
+          },
+        },
+        'justification_blob.criterion': {
+          text: {
+            type: 'text',
+            metadata_field: false,
+          },
+        },
+        justification_blob: {
+          object: {
+            type: 'object',
+            metadata_field: false,
+          },
+        },
+        'justification_blob.shallow.jsi.sdb.dsel2.bootlegged-gille.botness': {
+          float: {
+            type: 'float',
+            metadata_field: false,
+          },
+        },
+        'justification_blob.shallow.jsi.sdb.dsel2.bootlegged-gille.general_algorithm_score': {
+          float: {
+            type: 'float',
+            metadata_field: false,
+          },
+        },
+        'justification_blob.shallow.jsi.sdb.dsel2.uncombed-boris.botness': {
+          float: {
+            type: 'float',
+            metadata_field: false,
+          },
+        },
+        'justification_blob.shallow.jsi.sdb.dsel2.uncombed-boris.general_algorithm_score': {
+          float: {
+            type: 'float',
+            metadata_field: false,
+          },
+        },
+        overall_vote_score: {
+          float: {
+            type: 'float',
+            metadata_field: false,
+          },
+        },
+        _index: {
+          _index: {
+            type: '_index',
+            metadata_field: true,
+          },
+        },
+      },
+      indices: ['[test-]YYYY.MM.DD'],
+    };
+
+    it('should not retry when ES is down', async () => {
+      config.featureToggles.elasticsearchCrossClusterSearch = true;
+      const twoDaysBefore = toUtc().subtract(2, 'day').format('YYYY.MM.DD');
+      const ds = createElasticDatasource({
+        jsonData: { interval: 'Daily' },
+      });
+
+      ds.getResource = jest.fn().mockImplementation((options) => {
+        if (options.url === `test-${twoDaysBefore}/_field_caps`) {
+          return of({
+            data: {},
+          });
+        }
+        return throwError({ status: 500 });
+      });
+
+      const timeRange = { from: 1, to: 2 } as unknown as TimeRange;
+      await expect(ds.getFields(undefined, timeRange)).toEmitValuesWith((received) => {
+        expect(received.length).toBe(1);
+        expect(received[0]).toStrictEqual({ status: 500 });
+        expect(ds.getResource).toBeCalledTimes(1);
+      });
+    });
+
+    it('should not retry more than 7 indices', async () => {
+      config.featureToggles.elasticsearchCrossClusterSearch = true;
+      const ds = createElasticDatasource({
+        jsonData: { interval: 'Daily' },
+      });
+
+      ds.getResource = jest.fn().mockImplementation(() => {
+        return throwError({ status: 404 });
+      });
+
+      const timeRange = createTimeRange(dateTime().subtract(2, 'week'), dateTime());
+
+      await expect(ds.getFields(undefined, timeRange)).toEmitValuesWith((received) => {
+        expect(received.length).toBe(1);
+        expect(received[0]).toStrictEqual('Could not find an available index for this time range.');
+        expect(ds.getResource).toBeCalledTimes(7);
+      });
+    });
+
+    it('should return nested fields', async () => {
+      config.featureToggles.elasticsearchCrossClusterSearch = true;
+      const ds = createElasticDatasource({
+        jsonData: { interval: 'Daily' },
+      });
+
+      ds.getResource = jest.fn().mockResolvedValue(getFieldsMockData);
+
+      await expect(ds.getFields()).toEmitValuesWith((received) => {
+        expect(received.length).toBe(1);
+
+        const fieldObjects = received[0];
+        const fields = map(fieldObjects, 'text');
+        expect(fields).toEqual([
+          '@timestamp_millis',
+          'classification_terms',
+          'ip_address',
+          'justification_blob.criterion.keyword',
+          'justification_blob.criterion',
+          'justification_blob.shallow.jsi.sdb.dsel2.bootlegged-gille.botness',
+          'justification_blob.shallow.jsi.sdb.dsel2.bootlegged-gille.general_algorithm_score',
+          'justification_blob.shallow.jsi.sdb.dsel2.uncombed-boris.botness',
+          'justification_blob.shallow.jsi.sdb.dsel2.uncombed-boris.general_algorithm_score',
+          'overall_vote_score',
+        ]);
+      });
+    });
+    it('should return number fields', async () => {
+      config.featureToggles.elasticsearchCrossClusterSearch = true;
+      ds.getResource = jest.fn().mockResolvedValue(getFieldsMockData);
+
+      await expect(ds.getFields(['number'])).toEmitValuesWith((received) => {
+        expect(received.length).toBe(1);
+
+        const fieldObjects = received[0];
+        const fields = map(fieldObjects, 'text');
+        expect(fields).toEqual([
+          'justification_blob.shallow.jsi.sdb.dsel2.bootlegged-gille.botness',
+          'justification_blob.shallow.jsi.sdb.dsel2.bootlegged-gille.general_algorithm_score',
+          'justification_blob.shallow.jsi.sdb.dsel2.uncombed-boris.botness',
+          'justification_blob.shallow.jsi.sdb.dsel2.uncombed-boris.general_algorithm_score',
+          'overall_vote_score',
+        ]);
+      });
+    });
+
+    it('should return date fields', async () => {
+      config.featureToggles.elasticsearchCrossClusterSearch = true;
+      ds.getResource = jest.fn().mockResolvedValue(getFieldsMockData);
+
+      await expect(ds.getFields(['date'])).toEmitValuesWith((received) => {
+        expect(received.length).toBe(1);
+
+        const fieldObjects = received[0];
+        const fields = map(fieldObjects, 'text');
+        expect(fields).toEqual(['@timestamp_millis']);
+      });
+    });
+  });
 });
