@@ -1,18 +1,17 @@
-import { createContext, useCallback, useContext } from 'react';
 import { Action } from '@reduxjs/toolkit';
+import { createContext, useCallback, useContext } from 'react';
 
 export type Reducer<S, A extends Action> = (state: S, action: A) => S;
 
-export const combineReducers = <S, A extends Action = Action>(reducers: { [P in keyof S]: Reducer<S[P], A> }) => (
-  state: S,
-  action: A
-): Partial<S> => {
-  const newState = {} as S;
-  for (const key in reducers) {
-    newState[key] = reducers[key](state[key], action);
-  }
-  return newState;
-};
+export const combineReducers =
+  <S, A extends Action = Action>(reducers: { [P in keyof S]: Reducer<S[P], A> }) =>
+  (state: S, action: A): Partial<S> => {
+    const newState = {} as S;
+    for (const key in reducers) {
+      newState[key] = reducers[key](state[key], action);
+    }
+    return newState;
+  };
 
 export const useStatelessReducer = <State, A = Action>(
   onChange: (value: State) => void,
